# coding: utf-8

"""
    Pulp 3 API

    Fetch, Upload, Organize, and Distribute Software Packages

    The version of the OpenAPI document: v3
    Contact: pulp-list@redhat.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from pulpcore.client.pulp_ansible.models.ansible_collection_version_response import AnsibleCollectionVersionResponse

class TestAnsibleCollectionVersionResponse(unittest.TestCase):
    """AnsibleCollectionVersionResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> AnsibleCollectionVersionResponse:
        """Test AnsibleCollectionVersionResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `AnsibleCollectionVersionResponse`
        """
        model = AnsibleCollectionVersionResponse()
        if include_optional:
            return AnsibleCollectionVersionResponse(
                prn = '',
                pulp_labels = {
                    'key' : ''
                    },
                artifact = '',
                pulp_created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                pulp_last_updated = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                pulp_href = '',
                sha256 = '',
                md5 = '',
                sha1 = '',
                sha224 = '',
                sha384 = '',
                sha512 = '',
                id = '',
                authors = [
                    ''
                    ],
                dependencies = pulpcore.client.pulp_ansible.models.dependencies.dependencies(),
                description = '',
                documentation = '',
                homepage = '',
                issues = '',
                license = [
                    ''
                    ],
                name = '',
                namespace = '',
                origin_repository = '',
                tags = [
                    pulpcore.client.pulp_ansible.models.ansible/tag_response.ansible.TagResponse(
                        name = '', )
                    ],
                version = '',
                requires_ansible = ''
            )
        else:
            return AnsibleCollectionVersionResponse(
        )
        """

    def testAnsibleCollectionVersionResponse(self):
        """Test AnsibleCollectionVersionResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
