# coding: utf-8

"""
    Pulp 3 API

    Fetch, Upload, Organize, and Distribute Software Packages

    The version of the OpenAPI document: v3
    Contact: pulp-list@redhat.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from pulpcore.client.pulp_ansible.api.pulp_ansible_artifacts_collections_v3_api import PulpAnsibleArtifactsCollectionsV3Api


class TestPulpAnsibleArtifactsCollectionsV3Api(unittest.TestCase):
    """PulpAnsibleArtifactsCollectionsV3Api unit test stubs"""

    def setUp(self) -> None:
        self.api = PulpAnsibleArtifactsCollectionsV3Api()

    def tearDown(self) -> None:
        pass

    def test_create(self) -> None:
        """Test case for create

        Upload a collection
        """
        pass

    def test_create_0(self) -> None:
        """Test case for create_0

        Upload a collection
        """
        pass

    def test_create_1(self) -> None:
        """Test case for create_1

        Upload a collection
        """
        pass

    def test_create_2(self) -> None:
        """Test case for create_2

        Upload a collection
        """
        pass


if __name__ == '__main__':
    unittest.main()
